import 'package:meta/meta.dart';
import 'package:zhiying_base_widget/pages/upload_wechat_page/model/upload_wechat_model.dart';

@immutable
abstract class UploadWeChatState {}

/// 初始化
class UploadWeChatInitial extends UploadWeChatState {}

/// 初始化失败
class UploadWeChatInitErrorState extends UploadWeChatState{}

/// 数据加载成功
class UploadWeChatLoadedState extends UploadWeChatState {
  UploadWeChatModel model;

  UploadWeChatLoadedState({this.model});
}

/// 上传信息成功
class UploadWeChatSubmitSuccessState extends UploadWeChatState {}

/// 上传信息失败
class UploadWeChatSubmitErrorState extends UploadWeChatState {}
